@@ -1,11 +1,11 @@
 #plot histogram that across multiple chromosomes
-rc.plot.mHistogram=function(Data, track.id, data.col=NULL, color.col=NULL, color.gradient=NULL, fixed.height=FALSE, track.color=NA, track.border=NULL, custom.track.height=NULL){
+rc.plot.mHistogram=function(Data, track.id, data.col=NULL, color.col=NULL, color.gradient=NULL, fixed.height=FALSE, track.color=NA, track.border=NULL, polygon.border=NULL, custom.track.height=NULL, max.value=NULL){
 	rc.check.mHistogramData(Data,data.col,color.col)
-	rc.plot.track(track.id,border=track.border,col=track.color)
+	rc.plot.track(track.id,border=track.border,col=track.color,custom.track.height=custom.track.height)
 	rcPar=rc.get.params()
 	chromPar=rc.get.chrom()
 	if(is.null(data.col)) fixed.height=TRUE
-	mx=ifelse(fixed.height==TRUE && is.null(color.gradient),1,max(Data[,data.col],na.rm=TRUE))
+	if(is.null(max.value)) max.value=ifelse(fixed.height==TRUE && is.null(color.gradient),1,max(Data[,data.col],na.rm=TRUE))
 	if(is.null(custom.track.height)) custom.track.height=rcPar$track.height
 	for(i in 1:nrow(Data)){
 		Chr1=Data[i,'Chr1']
@@ -16,7 +16,7 @@ rc.plot.mHistogram=function(Data, track.id, data.col=NULL, color.col=NULL, color
 		cumEnd = Data[i,'End2'] - iChr2['Start'] + 1 + iChr2['cumStart']
 		Col=NA
 		if(! is.null(color.gradient)){
-			cid=floor(Data[i,data.col]*length(color.gradient)/mx)
+			cid=floor(Data[i,data.col]*length(color.gradient)/max.value)
 			Col=color.gradient[max(cid,1)]
 		}else if(! is.null(color.col)){
 			Col=Data[i,color.col]
@@ -24,9 +24,9 @@ rc.plot.mHistogram=function(Data, track.id, data.col=NULL, color.col=NULL, color
 			Col=rcPar$color.hist
 		}
 		if((! is.na(Col)) && Col=='white') Col=NA
-		thick=ifelse(fixed.height,custom.track.height,custom.track.height*Data[i,data.col]/mx)
-		pos.xy <- rc.get.ringCoordinates(track.id,Start=cumStart,End=cumEnd,ringThickness=thick)
-		polygon(pos.xy$x, pos.xy$y, col=Col, border=NA);
+		thick=ifelse(fixed.height,custom.track.height,custom.track.height*Data[i,data.col]/max.value)
+		pos.xy <- rc.get.trackCoordinates(track.id,Start=cumStart,End=cumEnd,trackThickness=thick)
+		polygon(pos.xy$x, pos.xy$y, col=Col, border=polygon.border);
 	}
 	return(invisible())
 }
