@@ -9,7 +9,7 @@ rc.plot.track=function(track.id, border='black', col=NA, custom.track.height=NUL
 		iChr=chromPar[[i]]
 		Start=iChr['Start']
 		End=iChr['End']
-		pos.xy <- rc.get.ringCoordinates(track.id,Start=Start,End=End,Chr=Chr)
+		pos.xy <- rc.get.trackCoordinates(track.id,Start=Start,End=End,Chr=Chr)
 		polygon(pos.xy$x, pos.xy$y, border=border, col=col);
 	}
 	return(invisible())
